==> haskell-persistent-2.7.3.1-44-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.3.1
id: persistent-2.7.3.1-JPizRwY5rYB3EcraI0NZxt
key: persistent-2.7.3.1-JPizRwY5rYB3EcraI0NZxt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Raw.QQ
                Database.Persist.Sql.Run Database.Persist.Sql.Class
                Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: 14c8dda21b33f81e30a24e7fc8d59dd8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/persistent-2.7.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/persistent-2.7.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/persistent-2.7.3.1
hs-libraries: HSpersistent-2.7.3.1-JPizRwY5rYB3EcraI0NZxt
depends:
    base-4.10.1.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz containers-0.5.10.2
    conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6
    resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2
    path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu
    http-api-data-0.3.8.1-2hj8BHnFQJyAux68kXsXpu
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    monad-logger-0.3.28.3-J9ntO8Vvcx011zHhLkmBM6
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    template-haskell-2.12.0.0
    haskell-src-meta-0.8.0.2-HAINjqkby1O1rbgw8760E0
    blaze-html-0.9.0.1-4OJxrIJKFBtLtijPqODCyq
    blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3
    silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    fast-logger-2.4.11-AVUe0tBLFwYB24KvDBeruH
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=646a828923d0db6af349cf54aae99894
             resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2=dc9bedd5baacc22688739eb21b98c2f7
             path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu=836d2f307ab364d7fb9bc7fb26b0e5fe
             http-api-data-0.3.8.1-2hj8BHnFQJyAux68kXsXpu=8823a7a4e41677c4ba056e1b200d8c0d
             aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             monad-logger-0.3.28.3-J9ntO8Vvcx011zHhLkmBM6=c45005fd5b94975057e448c9bbc4dd1b
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             haskell-src-meta-0.8.0.2-HAINjqkby1O1rbgw8760E0=13e60ddf8ddd607bd55952f7c6f7bf68
             blaze-html-0.9.0.1-4OJxrIJKFBtLtijPqODCyq=5e2cd3879602ce26e9a3d86b5343f1fb
             blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3=89f2a92574468b60b114253ec4e21006
             silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3=d2dd9be64414e7e060e4b54fbebd65e8
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             fast-logger-2.4.11-AVUe0tBLFwYB24KvDBeruH=5ee8b14d00e031ab7c15b579e6a81c04
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.7.3.1-48-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.3.1
id: persistent-2.7.3.1-KfamkbJfgMzBGof3Q5Aou9
key: persistent-2.7.3.1-KfamkbJfgMzBGof3Q5Aou9
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Raw.QQ
                Database.Persist.Sql.Run Database.Persist.Sql.Class
                Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: 9fb3fcc87e9daa5807973f3759178fa9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/persistent-2.7.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/persistent-2.7.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/persistent-2.7.3.1
hs-libraries: HSpersistent-2.7.3.1-KfamkbJfgMzBGof3Q5Aou9
depends:
    base-4.10.1.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz containers-0.5.10.2
    conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg
    resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4
    exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00
    lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6
    resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2
    path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu
    http-api-data-0.3.8.1-2hj8BHnFQJyAux68kXsXpu
    aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF
    monad-logger-0.3.28.5-IB6Vt0QORO2DXfKjwuIBTc
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    template-haskell-2.12.0.0
    haskell-src-meta-0.8.0.2-HAINjqkby1O1rbgw8760E0
    blaze-html-0.9.0.1-LSl5YsnAOxGGQxRTreTaG0
    blaze-markup-0.8.2.1-EXmhw0576TBGsUq0laKKM2
    silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    fast-logger-2.4.11-AVUe0tBLFwYB24KvDBeruH
    scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             conduit-1.2.13-KGlTp1YFxNbGMkHuibtdAg=f28c447a2bec9bcfe4989e0ac67614c0
             resourcet-1.1.11-3TsXMCE9bmqJOgo1a6gjl4=5d5f7a5bec88091b43d999202511397f
             exceptions-0.8.3-FtqgxeR4VUg9hGcIqYr2bq=349f1b5172af08123dc6c444b05979b3
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=48449fd048b5d0ad9ccb1feb773de43b
             lifted-base-0.2.3.12-FdTgiCxwnvG4bzcNeii3f6=646a828923d0db6af349cf54aae99894
             resource-pool-0.2.3.2-JnmLkNozjiKHQJsjkBGvI2=dc9bedd5baacc22688739eb21b98c2f7
             path-pieces-0.2.1-BbZOveR2lVe9KIkwmleWEu=836d2f307ab364d7fb9bc7fb26b0e5fe
             http-api-data-0.3.8.1-2hj8BHnFQJyAux68kXsXpu=8823a7a4e41677c4ba056e1b200d8c0d
             aeson-1.2.4.0-IxpmF2XxtfM2bzjPAR2gMF=117e2ccb320a02562b7dab8dac8cab03
             monad-logger-0.3.28.5-IB6Vt0QORO2DXfKjwuIBTc=b7a3f9016c354ccfebf1a575c085f679
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             unordered-containers-0.2.9.0-AIQ8bV884oMFcq0To2pA1G=5c8877e146af6c27c44eb74d4cb22e80
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             haskell-src-meta-0.8.0.2-HAINjqkby1O1rbgw8760E0=13e60ddf8ddd607bd55952f7c6f7bf68
             blaze-html-0.9.0.1-LSl5YsnAOxGGQxRTreTaG0=49a468374da15ee6981f2dc0c5ca6996
             blaze-markup-0.8.2.1-EXmhw0576TBGsUq0laKKM2=2957175f80d486950ba665dd719601e4
             silently-1.2.5-A7WEXUoXcTh1TcbS3dokt3=d2dd9be64414e7e060e4b54fbebd65e8
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             fast-logger-2.4.11-AVUe0tBLFwYB24KvDBeruH=5ee8b14d00e031ab7c15b579e6a81c04
             scientific-0.3.5.3-4Af2QhuNyMzGatzrYjrxpI=a27ded325e5d5959c97ff2a5817450bc
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
